#delimit ;
set more off;
cap log close;
set mem 400000;


cd "E:\RA\NLSY\FINAL_FILES\";
log using "Logs\_hrp_statistics.log", replace;



**************************************************************************
**    This file calculates summary statistics of hours worked and		**
**	  rates of pay for all individuals.						**
**	It calls on hrp_averages.do which itself calls on weekly_hrp.do	**
**************************************************************************
** Input files:  	_weeklyfile2_*.dta						**
**			hrp_*_byage.dta							**
**			age_calc.do								**
**												**
** Output files: 	hist_hrp_1.dta							**
**			hrphistm_1.gph							**
**												**	
**												**
**		Christine Neill, Feb 2005 (christine.neill@utoronto.ca)	**
**************************************************************************;





**************************************************************************************************************
This file takes data created by _hrptojobno.do and calculates 
statistics on the distribution of hourly rates of pay.  First have to call the file hrp_averages which itself
calls the file weekly_hrp
**************************************************************************************************************;
** This line is just to get the intermediate files - can turn it off in the end if you want;
do "Do\hrp_averages.do";

clear;


** Need to get the number of children a woman has at any given age
	Will use _weeklyfile2_women.dta to get it (though there are easier sources)
	Will keep number of children under 6, under 18, and everk, as well as creating
	a new variable called childstatus = 0 if never have kids, =1 if have kids at some point
	but not yet, =2 if have had children;
*****;



use "My Statistics\_weeklyfile2_women.dta", clear;

keep ID week everk nkborn nku6 nku18 ageyownk;

do "Do\age_calc.do";

gen minnku6 = nku6;
gen minnku18 = nku18;
rename nku6 maxnku6;
rename nku18 maxnku18;

sort ID week;
collapse (min) everk nkborn minnku6 minnku18 ageyownk (max) maxnku6 maxnku18, by(ID age);
sort ID age;
merge (ID age) using "My Statistics\hrp_women_byage.dta";

tab _merge;
drop _merge;
sort ID age;

append using "My Statistics\hrp_men_byage.dta";
sort ID age;
gen sex = 0 if SAMP<=4;
replace sex = 1 if SAMP>4;




**  1.  distribution of wages at age 20;

gen  lavHRP = log(avHRP);
gen lmedHRP = log(medHRP);
sort sex ID age;

by sex: sum lavHRP lmedHRP if age==20;
tabstat avHRP medHRP lavHRP lmedHRP, s(n mean sd max min p50 p5 p95) c(s) by(sex); 

** 2.  distribution of wages by age, from 20-40 (note: 40 is getting low on numbers of observations);
**  Do not include outliers - the top and bottom 2.5% of the distribution;

sort sex age;
by sex age: egen low5 = pctile(avHRP), p(2.5);
by sex age: egen high5 = pctile(avHRP), p(97.5);

***********************************************************************************************************;
** This table gives most of the HRP data used in the paper;

by sex: tabstat avHRP if avHRP>low5 & avHRP<high5, s(n mean p1 p5 p10 p25 p50 p75 p90 p95 p99) c(s) by(age);
***********************************************************************************************************;

sort everk age;
gen childstatus = 0 if everk==0;
replace childstatus = 1 if everk==1 & nkborn==0;
replace childstatus = 2 if everk==1 & nkborn~=0 & sex==1;
sort childstatus age;
by childstatus: tabstat avHRP if avHRP>low5 & avHRP<high5, s(n mean p1 p5 p25 p50 p75 p90 p95 p99) c(s) by(age); 


**3.  Charts;

* a is a count variable;
gen a = 1; 
gen  hrpgroup = 1 if avHRP>0 & avHRP<=400;
replace hrpgroup = 2 if avHRP>400 & avHRP<=800;
replace hrpgroup = 3 if avHRP>800 & avHRP<=1200;
replace hrpgroup = 4 if avHRP>1200 & avHRP<=1600;
replace hrpgroup = 5 if avHRP>1600 & avHRP<=2000;
replace hrpgroup = 6 if avHRP>2000;

label define hrpgv 1 "<=$4" 2 "$4-$8" 3 "$8-$12" 4 "$12-$16" 5 "$16-$20" 6">$20";
label values hrpgroup hrpgv;

gen a1 = 0 if age<20;
replace a1 = 1 if age>=20 & age<25;
replace a1 = 2 if age>=25 & age<30;
replace a1 = 3 if age>=30 & age<35;
replace a1 = 4 if age>=35 & age<40;
replace a1 = 5 if age>=40 & age<45;
replace a1 = 6 if age>=45;
label define a1v 1 "20-24" 2 "25-29" 3 "30-34" 4 "35-39" 5 "40-44";

label values a1 a1v;


preserve;
keep if avHRP>low5 & avHRP<high5;
gen INC = 1 if SAMP<5;
replace INC = 2 if SAMP>=5;
label define INCv 1 "Male" 2 "Female";
label values INC INCv;

	collapse (sum) a, by(hrpgroup INC a1);
	
	save "My Statistics\histograms\hist_hrp_1.dta", replace;
	sort INC a1;
	by INC a1: egen tot = sum(a);
	gen pc = a/tot*100;

	gen group = INC*10+a1;
	drop a tot INC a1;

	reshape i hrpgroup;
	reshape j group;
	reshape xij pc;
	reshape xi;
	reshape wide;

	label var pc11 "20-24";
	label var pc12 "25-29";
	label var pc13 "30-34";
	label var pc14 "35-39";
	label var pc15 "40-44";

	label var pc21 "20-24";
	label var pc22 "25-29";
	label var pc23 "30-34";
	label var pc24 "35-39";
	label var pc25 "40-44";

	graph pc11 pc12 pc13 pc14 pc15, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistm_1.gph", replace)
		ti("Men, HRP by age");
	graph pc21 pc22 pc23 pc24 pc25, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistf_1.gph", replace)
		ti("Women, HRP by age");


restore;

log close;
