#delimit ;
set more off;
set mem 500000;
cap log close;

** Change directory as necessary;
cd "E:\RA\NLSY\FINAL_FILES\";

****************************************************************
**  Creates _weeklyfile2.dta from NLSY tagsets.               **
**  Data is observed for each individual once every week.     **
**  Have got one variable per tagset in most cases.           **
**                                                            **
**             Christine Neill, Feb 2005                      **
**                  christine.neill@utoronto.ca               **
****************************************************************;

tempfile a;


** Do a rename, reshape and save of the job number files;
	do "rename\rename_job2to5.do";

clear;

**Read in weekly labour force status and hours for each year, rename, reshape and append;


** 1978-1979**;
	infile using "Tagsets\weekly_lstatus_79.DCT", clear;
		do "rename\rename_weekly_lstatus.do";
		sort ID week;
		save `a', replace;

	infile using "Tagsets\hrs_79.DCT", clear;
		do "rename\rename_hrs.do";
		sort ID week;

	merge (ID week) using `a';
	tab _merge;
	drop _merge;
	sort ID week;
	save "My Statistics\_weeklyfile2.dta", replace;
	

** And looping until 1998 (coz my naming conventions for the tagsets weren't great);

local t = 80;
while `t'<=98{;
	infile using "Tagsets\weekly_lstatus_`t'.DCT", clear;
		do "rename\rename_weekly_lstatus.do";
		sort ID week;
		save `a', replace;

	infile using "Tagsets\hrs_`t'.DCT", clear;
		do "rename\rename_hrs.do";
		sort ID week;

	merge (ID week) using `a';
	tab _merge;
	drop _merge;
	sort ID week;
	
	append using "My Statistics\_weeklyfile2.dta";
	sort ID week;
	save "My Statistics\_weeklyfile2.dta", replace;
	
	t = `t'+2;
};


** 1999-2000**;
	infile using "Tagsets\weekly_lstatus_00.DCT", clear;
		do "rename\rename_weekly_lstatus.do";
		sort ID week;
		save `a', replace;

	infile using "Tagsets\hrs_00.DCT", clear;
		do "rename\rename_hrs.do";
		sort ID week;

	merge (ID week) using `a';
	tab _merge;
	drop _merge;
	sort ID week;

	append using "My Statistics\_weeklyfile2.dta";
	sort ID week;
	compress;
	save "My Statistics\_weeklyfile2.dta", replace;


***************************************************
** _weeklyfile should now contain 3 variables:   **
**            y, lstatus, and hrs                **
***************************************************;

use "My Statistics\_weeklyfile2.dta", clear;

keep if SAMP<5;
sort ID week;
* merge in the job number information;

merge (ID week) using "My Statistics\weekly_j1to5_long_men.dta";
tab _merge;
keep if _merge==3;
drop _merge;

gen J1 = lstatus if lstatus>=100;
replace J1 = -4 if lstatus<100;

sort ID week;
compress;
save "My Statistics\_weeklyfile2_men.dta", replace;


clear;
use "My Statistics\_weeklyfile2.dta", clear;

keep if SAMP>4;
sort ID week;

merge (ID week) using "My Statistics\weekly_j1to5_long_women.dta";
tab _merge;
keep if _merge==3;
drop _merge;

gen J1 = lstatus if lstatus>=100;
replace J1 = -4 if lstatus<100;

sort ID week;

compress;
save "My Statistics\_weeklyfile2_women.dta", replace;



** Now need to merge in other aspects for women's file;
** Calculating the child-related files and statistics;

do "Do\childagemanip.do";

** Merge the file 'womenwithkids' into weeklyfile2_women;
clear;
use "My Statistics\_weeklyfile2_women.dta", clear;
merge (ID week) using "My Statistics\womenwithkids.dta";
tab _merge;
drop _merge;

mvencode everk nku6 nku18 nkborn, mv(0) override;
save "My Statistics\_weeklyfile2_women.dta", replace;

