#delimit ;
set more off;

**************************************************************************
**    This file creates variables used to summarise employment status	**
**	  and hours worked for all individuals.					**
** 	It is a subroutine used in _hrs_stats.do					**
**************************************************************************
** Input files:  	_weeklyfile2.dta							**
**			age_calc.do								**
**												**
**												**
** Output files: 										**
**												**
**												**	
**												**
**		Christine Neill, Feb 2005 (christine.neill@utoronto.ca)	**
**************************************************************************;





use "My Statistics\_weeklyfile2_men.dta", clear;

drop J1-J5;

** first have to assign ages for individuals in each week;

do "Do\age_calc.do";


** Drop if age<20;

drop if age<20;


gen a1 = 1 if age<25;
replace a1 = 2 if age>=25 & age<30;
replace a1 = 3 if age>=30 & age<35;
replace a1 = 4 if age>=35 & age<40;
replace a1 = 5 if age>=40 & age<45;
replace a1 = 6 if age>=45;

label define a1v 1 "20-24" 2 "25-29" 3 "30-34" 4 "35-39" 5 "40-44";
label values a1 a1v;

** Generating labour force status dummies;
	gen is = 1 if hrs<0;
	replace is = 0 if is~=1;


	qui gen N = 1 if lstatus>100;
	qui gen UN = 1 if lstatus == 4;
	qui gen OLF = 1 if lstatus == 5;
	qui gen MIL = 1 if lstatus == 7;
	qui gen NOB = 1 if lstatus == 0;
	qui gen NW = 1 if lstatus == 2;
	qui gen EU = 1 if lstatus == 3;
	qui mvencode N UN OLF MIL NOB NW EU, mv(0);
	
	qui gen LF = N+UN+EU+NW;
*  For consistency over time (and to be a bit more serious);
replace hrs=98 if hrs>98;

gen FT = 1 if N==1 & hrs>=35;
replace FT = 0 if FT~=1;
gen PT = 1 if N==1 & hrs<35;
replace PT = 0 if PT~=1;
label var FT "Working full time";
label var PT "Working part time";
gen NT = 1 - FT - PT;
label var NT "Not working, unadjusted for unobserved status";

	compress;
	
	gen wNo = 1-NOB;
label var wNo "Employment status observed";
	gen who = 1 if NOB==0 & is==0;
label var who "Employment status observed, no invalid skip on hours";
	gen wwho = 1 if (N==1|EU==1) & is==0;
label var wwho "Working, no invalid skip on hours";
	gen wpho = 1 if hrs>0;
label var wpho "Working, positive hours worked";


drop OLF MIL NW EU is;

mvencode wwho who wpho , mv(0);





compress;

