#delimit ;
set more off;

cd "E:\RA\NLSY\FINAL_FILES\";



use "My Statistics\_weeklyfile2_women.dta", clear;

do "Do\age_calc.do";

** Generating labour force status dummies;
** Dropping all weeks with unobserved labour force status;

	gen status = 2;
	replace status = 0 if lstatus==0;
	replace status = 1 if lstatus>100;
	replace status = 1 if lstatus==3;


	gen MIL= 1 if lstatus==7;

sort ID week;


by ID: gen lagstatus =status[_n-1];
by ID: gen leadstatus = status[_n+1];

by ID: gen dstatus = status-lagstatus;
gen periodS = 0;
replace periodS = 1 if dstatus~=0;
gen periodE = 1 if status-leadstatus~=0;
replace periodE = 0 if periodE~=1;

by ID: gen period = sum(periodS);

gen nkstart = nkborn*periodS;
gen nkend = nkborn*periodE;
gen aykend = ageyownk*periodE;

gen weekmin=week;
gen weekmax=week;

gen agemin = age;
rename age agemax;

collapse (max) SAMP status MIL weekmax nkstart nkend aykend agemax (min) weekmin agemin, by(ID period);

sort ID weekmin;
gen LT = 1 if weekmin==1;
gen RT = 1 if weekmax==1200;
by ID : replace LT=1 if status[_n-1]==0;
by ID : replace RT=1 if status[_n+1]==0;

gen gap = 1 if status==2;
by ID: gen gapno = sum(gap);

gen emp = 1 if status==1;
by ID: gen empno=sum(emp);


gen length = weekmax-weekmin+1;
sum length if gap==1;

gen lengthbin = length;
replace lengthbin = 1 if length>1& length<6;
replace lengthbin = 2 if length>5&length<11;
replace lengthbin = 3 if length>10&length<21;
replace lengthbin = 4 if length>20& length<31;
replace lengthbin = 5 if length>30&length<41;
replace lengthbin = 6 if length>40&length<51;
replace lengthbin = 7 if length>50 & length<61;
replace lengthbin = 8 if length>60 & length<71;
replace lengthbin = 9 if length>70 & length<81;
replace lengthbin = 10 if length>80;
cap label define lengthbinv 1 "1-5" 2 "6-10" 3 "11-20" 4 "21-30" 5 "31-40" 6 "41-50" 7 "51-60" 8"61-70" 9"71-80" 10">80";
label  values  lengthbin lengthbinv;


sum gapno;
tab gapno;

sort ID weekmin;
save "My Statistics\jobgaps_women.dta", replace;

**********************************************************************************************************;
*Now we calculate the statistics;
** For women only;

keep if SAMP>=5;

sort ID weekmin;


** Summarises the gaps in employment;
sum gapno;
tab gapno;
sum length if gap==1;
sum length if gap==1 & LT~=1 & RT~=1;
kdensity length if gap ==1, saving("E:\RA\NLSY\My Statistics\_gaps_density_gap_f.gph", replace) xlab ylab;
hist lengthbin if gap==1, ylab saving("E:\RA\NLSY\My Statistics\_gaps_hist_gap_f.gph", replace) ;
tab lengthbin if gap==1;


** Summarises the periods of employment;
sum empno;
tab empno;
sum length if emp==1;
kdensity length if emp==1, saving("E:\RA\NLSY\My Statistics\_gaps_density_emp_f.gph", replace) xlab ylab;
hist lengthbin if emp==1, ylab saving("E:\RA\NLSY\My Statistics\_gaps_hist_emp_f.gph", replace) ;
tab lengthbin if emp==1;


** Summarises by whether it is a period when a child is born or not;
gen childborn = nkend-nkstart;
replace childborn = 0 if childborn<1;
sum childborn;

sort childborn;
by childborn: sum length if gap==1;
tab lengthbin childborn if childborn<=1 & gap==1;

sort nkend;
by nkend: sum length if gap==1;
by nkend: tab lengthbin if gap==1;

**************************
**************************
** TABLE 3 from the paper (women's column only);
* Average number of non-employment spells;
gen gapg6 = 1 if gap==1 & length>6;
sort ID;
by ID: gen gapg6no = sum(gapg6);
label var gapg6no "Number of gaps of greater than six weeks";
sum gapg6no;
* Should be mean 2.9 sd 2.5;
**distribution - percentages should be 55,23,22;
gen gapg6d = 1 if gapg6no<=2;
replace gapg6d = 2 if gapg6no>2 & gapg6no<=4;
replace gapg6d = 3 if gapg6no>4;
tab gapg6d;
**average length (weeks) - 41 (sd71);
sum length if gapg6==1;
sum length if gapg6==1 & LT~=1 & RT~=1;

** If collapse by individual;
preserve;
gen lgapg6 = length if gap==1 & length>=6;
gen lgap = length if gap==1;

collapse (mean) lgapg6 lgap (max)gapno gapg6no, by(ID);
sum lgap lgapg6 gapno gapg6no;
gen d1 = 1 if gapg6no<=2;
replace d1 = 2 if gapg6no>2 & gapg6no<=4;
replace d1 = 3 if gapg6no>4;
tab d1;
restore;
****************************
****************************
**   TABLE 4 from the paper  (women's column only);
gen qtlygap = 1 if length>6 & length<=19;
replace qtlygap = 2 if length>19 & length<=32;
replace qtlygap = 3 if length>32 & length<=45;
replace qtlygap = 4 if length>45 & length<=58;
replace qtlygap = 5 if length>58;
tab qtlygap if gap==1;
******************************;



****  Accounting for gaps of unknown status;
**  Assign a gap between two observed periods whose status is unknown to the status before the gap;

sort ID period;
gen intnonobs = 1 if status==0 & weekmin~=1 & weekmax~=1200;
gen status2 = status;
gen change = 1 if intnonobs==1;
replace change = 0 if change~=1;
replace status2 = status[_n-1] if change==1;

sort ID period;
by ID: gen dstatus2 = status2-status2[_n-1];
gen periodS2 = 0;
replace periodS2 = 1 if dstatus2~=0;
by ID: gen period2 = sum(periodS);


collapse (max) SAMP status weekmax nkend aykend agemax change (min) weekmin agemin nkstart, by(ID period2);

sort ID weekmin;
gen LT = 1 if weekmin==1;
gen RT = 1 if weekmax==1200;
by ID : replace LT=1 if status[_n-1]==0;
by ID : replace RT=1 if status[_n+1]==0;

gen gap = 1 if status==2;
by ID: gen gapno = sum(gap);

gen emp = 1 if status==1;
by ID: gen empno=sum(emp);

gen length = weekmax-weekmin+1;

gen lengthbin = length;
replace lengthbin = 1 if length>1& length<6;
replace lengthbin = 2 if length>5&length<11;
replace lengthbin = 3 if length>10&length<21;
replace lengthbin = 4 if length>20& length<31;
replace lengthbin = 5 if length>30&length<41;
replace lengthbin = 6 if length>40&length<51;
replace lengthbin = 7 if length>50 & length<61;
replace lengthbin = 8 if length>60 & length<71;
replace lengthbin = 9 if length>70 & length<81;
replace lengthbin = 10 if length>80;

label  values  lengthbin lengthbinv;


sum gapno;
tab gapno;
sum length if gap==1;
sum length if gap==1 & LT~=1 & RT~=1;
kdensity length if gap ==1, saving("E:\RA\NLSY\My Statistics\_gaps_density_gap_f2.gph", replace) xlab ylab;
hist lengthbin if gap==1, ylab saving("E:\RA\NLSY\My Statistics\_gaps_hist_gap_f2.gph", replace) ;
tab lengthbin if gap==1;

sum empno;
tab empno;
sum length if emp==1;
kdensity length if emp==1, saving("E:\RA\NLSY\My Statistics\_gaps_density_emp_f2.gph", replace) xlab ylab;
hist lengthbin if emp==1, ylab saving("E:\RA\NLSY\My Statistics\_gaps_hist_emp_f2.gph", replace) ;
tab lengthbin if gap==1;


gen childborn = nkend-nkstart;
replace childborn = 0 if childborn<1;
sum childborn;

sort childborn;
by childborn: sum length if gap==1;
tab lengthbin if childborn>=1 & gap==1;
tab lengthbin if childborn==0 & gap==1;

sort nkend;
by nkend: sum length if gap==1;
by nkend: tab lengthbin if gap==1;

**************************
**************************
** TABLE 3 from the paper (women's column only);
* Average number of non-employment spells;
gen gapg6 = 1 if gap==1 & length>6;
sort ID;
by ID: gen gapg6no = sum(gapg6);
label var gapg6no "Number of gaps of greater than six weeks";
sum gapg6no;
* Should be mean 2.9 sd 2.5;
**distribution - percentages should be 55,23,22;
gen gapg6d = 1 if gapg6no<=2;
replace gapg6d = 2 if gapg6no>2 & gapg6no<=4;
replace gapg6d = 3 if gapg6no>4;
tab gapg6d;
**average length (weeks) - 41 (sd71);
sum length if gapg6==1;
sum length if gapg6==1 & LT~=1 & RT~=1;

gen kiddie = 0 if childborn == 0;
replace kiddie  =1 if childborn~=0;
gen lgapg6 = length if gap==1 & length>=6;
gen lgap = length if gap==1;

** If collapse by individual;
preserve;

collapse (mean) lgapg6 lgap (max)gapno gapg6no, by(ID);
sum lgap lgapg6 gapno gapg6no;

gen d1 = 1 if gapg6no<=2;
replace d1 = 2 if gapg6no>2 & gapg6no<=4;
replace d1 = 3 if gapg6no>4;
tab d1;
restore;

****************************
****************************
**   TABLE 4 from the paper  (women's column only);
gen qtlygap = 1 if length>6 & length<=19;
replace qtlygap = 2 if length>19 & length<=32;
replace qtlygap = 3 if length>32 & length<=45;
replace qtlygap = 4 if length>45 & length<=58;
replace qtlygap = 5 if length>58;
tab qtlygap if gap==1;
tab qtlygap if gap==1 & childborn==0;
tab qtlygap if gap==1 & childborn>=1;
******************************;




